const { series } = require('gulp');

var project_name = 'makeitopen', // Project name, used for build
    url = 'http://localhost:8181/'; // Local Development URL for BrowserSync

const gulp = require('gulp')
const jshint = require('gulp-jshint')
const browserSync = require('browser-sync')
const uglify = require('gulp-uglify')
const imagemin = require('gulp-imagemin')
const newer = require('gulp-newer')
const rename = require('gulp-rename')
const concat = require('gulp-concat')
const notify = require('gulp-notify')
const sass = require('gulp-sass')
const plumber = require('gulp-plumber')
const reload = browserSync.reload
const sourcemaps = require('gulp-sourcemaps')
const svgmin = require('gulp-svgmin')

function style() {
    return (
      gulp.src('./scss/*.scss')
	    .pipe(sourcemaps.init())
	    .pipe(sass({ outputStyle: 'compressed' }).on('error', sass.logError))
	    .pipe(sourcemaps.write('./maps/'))
	    .pipe(gulp.dest('./css/'))
	    .pipe(reload({ stream: true }))
	    .on('error', sass.logError)
	    .pipe(notify({ message: project_name + ': Style sass task complete', onLast: true }))
)}
exports.style = style;

function browserSyncReload(done) {
  browserSync.reload();
  done();
}

function javascript() {
    return (
      gulp.src(['./js/*.js', '!./js/*.min.js'])
      .pipe(plumber())
      .pipe(jshint())
      .pipe(jshint())
      .pipe(jshint.reporter('default'))
      .pipe(concat('concat.js'))
      .pipe(uglify())
      .pipe(rename('main.min.js'))
      .pipe(plumber.stop())
      .pipe(gulp.dest('./js/'))
      .pipe(reload({ stream: true }))
      .pipe(notify({ message: project_name + ': scripts task complete', onLast: true }))
)}
exports.javascript = javascript;

function watchFiles(){
  browserSync.init({
    proxy: url,
    notify: false,
    injectChanges: true
  });
  var filesToReload = [
    '../*.php',
    '../**/*.php',
    '../**/**/*.php',
    'img/*.{png,jpg,gif,svg}'
  ];

  gulp.watch([ 'js/*.js' ], javascript);
  gulp.watch([ 'scss/*.scss', 'scss/**/*.scss' ], style);
  gulp.watch(filesToReload, browserSyncReload);
} 
exports.watchFiles = watchFiles;

exports.default = series(style, watchFiles, javascript);
